netapp_ontap.resources.vscan_scanner_pool API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.vscan_scanner_pool`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

A scanner-pool defines the Vscan servers and privileged users that can connect to SVMs and a scanner policy or role determines whether a scanner-pool is active. You can configure a scanner-pool to be used on the local cluster or any other cluster in an MCC/DR setup.

## Examples

### Retrieving all fields for all scanner-pools of an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                VscanScannerPool.get_collection("<svm-uuid>", fields="*", return_timeout=15)
            )
        )

Try it out

    [
        VscanScannerPool(
            {
                "role": "primary",
                "privileged_users": ["cifs\\u1", "cifs\\u2"],
                "name": "scanner-1",
                "cluster": {
                    "name": "clus1",
                    "uuid": "3af387d8-6131-11ef-92d9-005056bbd354",
                },
                "servers": ["1.1.1.1", "10.72.204.27"],
                "svm": {"name": "vs1", "uuid": "1ccbefd6-6132-11ef-92d9-005056bbd354"},
            }
        ),
        VscanScannerPool(
            {
                "role": "secondary",
                "privileged_users": ["cifs\\u1", "cifs\\u2"],
                "name": "scanner-2",
                "cluster": {
                    "name": "clus1",
                    "uuid": "3af387d8-6131-11ef-92d9-005056bbd354",
                },
                "servers": ["1.1.1.1", "10.72.204.27"],
                "svm": {"name": "vs1", "uuid": "1ccbefd6-6132-11ef-92d9-005056bbd354"},
            }
        ),
    ]

### Retrieving all scanner-pools with role set as secondary

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        print(
            list(
                VscanScannerPool.get_collection(
                    "<svm-uuid>", role="secondary", fields="*", return_timeout=15
                )
            )
        )

Try it out

    [
        VscanScannerPool(
            {
                "role": "secondary",
                "privileged_users": ["cifs\\u1", "cifs\\u2"],
                "name": "scanner-2",
                "cluster": {
                    "name": "Cluster3",
                    "uuid": "0933f9b5-f226-11e8-9601-0050568ecc06",
                },
                "servers": ["1.1.1.1", "10.72.204.27"],
                "svm": {"name": "vs1", "uuid": "0e2f7c91-f227-11e8-9601-0050568ecc06"},
            }
        )
    ]

### Retrieving the specified scanner-pool associated with an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool(
            "0e2f7c91-f227-11e8-9601-0050568ecc06", name="scanner-1"
        )
        resource.get(fields="*")
        print(resource)

Try it out

    VscanScannerPool(
        {
            "role": "primary",
            "privileged_users": ["cifs\\u1", "cifs\\u2"],
            "name": "scanner-1",
            "cluster": {"name": "Cluster3", "uuid": "0933f9b5-f226-11e8-9601-0050568ecc06"},
            "servers": ["1.1.1.1", "10.72.204.27"],
            "svm": {"name": "vs1", "uuid": "0e2f7c91-f227-11e8-9601-0050568ecc06"},
        }
    )

### Creating a scanner-pool for an SVM with all fields specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool("b103be27-17b8-11e9-b451-0050568ecd85")
        resource.cluster = {
            "name": "Cluster1",
            "uuid": "ab746d77-17b7-11e9-b450-0050568ecd85",
        }
        resource.name = "test-scanner"
        resource.privileged_users = ["cifs\\u1", "cifs\\u2"]
        resource.role = "primary"
        resource.servers = ["1.1.1.1", "10.72.204.27"]
        resource.post(hydrate=True)
        print(resource)

Try it out

    VscanScannerPool(
        {
            "role": "primary",
            "privileged_users": ["cifs\\u1", "cifs\\u2"],
            "name": "test-scanner",
            "cluster": {"name": "Cluster1", "uuid": "ab746d77-17b7-11e9-b450-0050568ecd85"},
            "servers": ["1.1.1.1", "10.72.204.27"],
        }
    )

### Creating a scanner-pool for an SVM with an unspecified role and cluster

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool("b103be27-17b8-11e9-b451-0050568ecd85")
        resource.name = "test-scanner-1"
        resource.privileged_users = ["cifs\\u1", "cifs\\u2"]
        resource.servers = ["1.1.1.1", "10.72.204.27"]
        resource.post(hydrate=True)
        print(resource)

Try it out

    VscanScannerPool(
        {
            "privileged_users": ["cifs\\u1", "cifs\\u2"],
            "name": "test-scanner-1",
            "servers": ["1.1.1.1", "10.72.204.27"],
        }
    )

### Updating a scanner-pool for an SVM with all of the fields specified

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool(
            "0e2f7c91-f227-11e8-9601-0050568ecc06", name="test-scanner-1"
        )
        resource.cluster = {
            "name": "Cluster3",
            "uuid": "0933f9b5-f226-11e8-9601-0050568ecc06",
        }
        resource.privileged_users = ["cifs\\u1", "cifs\\u2"]
        resource.role = "secondary"
        resource.servers = ["1.1.1.1", "10.72.204.27"]
        resource.patch()

### Updating the "role" of a scanner-pool for an SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool(
            "0e2f7c91-f227-11e8-9601-0050568ecc06", name="test-scanner-1"
        )
        resource.cluster = {
            "name": "Cluster3",
            "uuid": "0933f9b5-f226-11e8-9601-0050568ecc06",
        }
        resource.role = "primary"
        resource.patch()

### Deleting a scanner-pool for a specified SVM

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import VscanScannerPool

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = VscanScannerPool(
            "0e2f7c91-f227-11e8-9601-0050568ecc06", name="test-scanner-1"
        )
        resource.delete()

## Classes

`class VscanScannerPool (*args, **kwargs)`

  Scanner pool is a set of attributes which are used to validate and manage connections between clustered ONTAP and external virus-scanning server, or "Vscan server".

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Static methods

  `def count_collection (*args, connection: HostConnection = None, **kwargs) -> int`

    Returns a count of all VscanScannerPool resources that match the provided query

    This calls GET on the object to determine the number of records. It is more efficient than calling get_collection() because it will not construct any objects. Query parameters can be passed in as kwargs to determine a count of objects that match some filtered criteria.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the count of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. These query parameters can affect the count. A return_records query param will be ignored.

    ## Returns

    On success, returns an integer count of the objects of this type. On failure, returns -1.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400, or if there is no connection available to use either passed in or on the library.

  `def delete_collection (*args, records: Iterable[ForwardRef('VscanScannerPool')] = None, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Deletes a Vscan scanner-pool configuration.
    Important notes: * The Vscan scanner-pool DELETE endpoint deletes all of the Vscan scanner-pools for a specified SVM. * If a Vscan is enabled, it requires at least one scanner-pool to be in the active state. Therefore, disable Vscan on the specified SVM so all the scanner-pools configured on that SVM can be deleted.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool delete`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Delete all objects in a collection which match the given query.

    All records on the host which match the query will be deleted.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to delete the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be deleted from the host.
    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be deleted.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def fast_get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[RawResource]`

    Returns a list of RawResources that represent VscanScannerPool resources that match the provided query

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def find (*args, connection: HostConnection = None, **kwargs) -> Resource`

    Retrieves the Vscan scanner-pool configuration of an SVM.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool show`
    - `vserver vscan scanner-pool privileged-users show`
    - `vserver vscan scanner-pool servers show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Find an instance of an object on the host given a query.

    The host will be queried with the provided key/value pairs to find a matching resource. If 0 are found, None will be returned. If more than 1 is found, an error will be raised or returned. If there is exactly 1 matching record, then it will be returned.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to find a bar for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `Resource` object containing the details of the object or None if no matches were found.

    ## Raises

    `NetAppRestError`: If the API call returned more than 1 matching resource.

  `def get_collection (*args, connection: HostConnection = None, max_records: int = None, **kwargs) -> Iterable[Resource]`

    Retrieves the Vscan scanner-pool configuration of an SVM.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool show`
    - `vserver vscan scanner-pool privileged-users show`
    - `vserver vscan scanner-pool servers show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Fetch a list of all objects of this type from the host.

        This is a lazy fetch, making API calls only as necessary when the result
        of this call is iterated over. For instance, if max_records is set to 5,
        then iterating over the collection causes an API call to be sent to the
        server once for every 5 records. If the client stops iterating before
        getting to the 6th record, then no additional API calls are made.

    ## Args

    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to get the collection of bars for a particular foo, the foo.name value should be passed.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `max_records`
      The maximum number of records to return per call
    `raw`
      return a list of `netapp_ontap.resource.RawResource` objects that require to be promoted before any RESTful operations can be used on them. Setting this argument to True makes get_collection substantially quicker when many records are returned from the server.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A list of `Resource` objects

    ## Raises

    `NetAppRestError`: If there is no connection available to use either passed in or on the library. This would be not be raised when get_collection() is called, but rather when the result is iterated.

  `def patch_collection (body: dict, *args, records: Iterable[ForwardRef('VscanScannerPool')] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> NetAppResponse`

    Updates the Vscan scanner-pool configuration of an SVM.
    Important notes: * Along with servers and privileged-users, the role of a scanner-pool can also be updated with the cluster on which a scanner-pool is allowed. * If role is specified and cluster isn't, then role is applied to the local cluster.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool modify`
    - `vserver vscan scanner-pool apply-policy`
    - `vserver vscan scanner-pool privileged-users add`
    - `vserver vscan scanner-pool privileged-users remove`
    - `vserver vscan scanner-pool servers remove`
    - `vserver vscan scanner-pool servers add`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Patch all objects in a collection which match the given query.

    All records on the host which match the query will be patched with the provided body.

    ## Args

    `body`
      A dictionary of name/value pairs to set on all matching members of the collection. The body argument will be ignored if records is provided.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to patch the collection of bars for a particular foo, the foo.name value should be passed.
    `records`
      Can be provided in place of a query. If so, this list of objects will be patched on the host.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post_collection (records: Iterable[ForwardRef('VscanScannerPool')], *args, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, connection: HostConnection = None, **kwargs) -> Union[List[VscanScannerPool], NetAppResponse]`

    Creates a Vscan scanner-pool configuration for a specified SVM. You can create a scanner-pool with all fields specified or only mandatory fields specified.
    Important notes: * A scanner-pool must have servers and privileged users specified. * If the role or cluster is not specified, the scanner-pool is created on the local cluster with the role set as primary. *`Only one of the fields cluster-uuid or cluster-name is required.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the Vscan configuration.
    - `name` - Scanner-pool name.
    - `privileged_users` - List of privileged users.
    - `servers` - List of server IP addresses or FQDNs.

    ### Recommended optional properties

    - `role` - Setting a role for a scanner-pool is recommended.
    - `cluster` - Passing the cluster name or UUID (or both) in a multi-cluster environment is recommended.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `role` - primary * `cluster.name` - Local cluster name. * `cluster.uuid` - Local cluster UUID.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool create`
    - `vserver vscan scanner-pool apply-policy`
    - `vserver vscan scanner-pool privileged-users add`
    - `vserver vscan scanner-pool servers add`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Send this collection of objects to the host as a creation request.

    ## Args

    `records`
      A list of `Resource` objects to send to the server to be created.
    `*args`
      Each entry represents a parent key which is used to build the path to the child object. If the URL definition were /api/foos/{foo.name}/bars, then to create a bar for a particular foo, the foo.name value should be passed.
    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of each object. When hydrate is set to True, poll must also be set to True.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host. Only resources matching this query will be patched.

    ## Returns

    A list of `Resource` objects matching the provided type which have been created by the host and returned. This is not the same list that was provided, so to continue using the object, you should save this list. If poll is set to False, then a `NetAppResponse` object is returned instead.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Methods

  `def delete (self, body: Union[Resource, dict] = None, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Deletes a Vscan scanner-pool configuration.
    Important notes: * The Vscan scanner-pool DELETE endpoint deletes all of the Vscan scanner-pools for a specified SVM. * If a Vscan is enabled, it requires at least one scanner-pool to be in the active state. Therefore, disable Vscan on the specified SVM so all the scanner-pools configured on that SVM can be deleted.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool delete`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Send a deletion request to the host for this object.

    ## Args

    `body`
      The body of the delete request. This could be a Resource instance or a dictionary object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will be sent as query parameters to the host.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the configuration of a specified scanner-pool of an SVM.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool show`
    - `vserver vscan scanner-pool privileged-users show`
    - `vserver vscan scanner-pool servers show`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the Vscan scanner-pool configuration of an SVM.
    Important notes: * Along with servers and privileged-users, the role of a scanner-pool can also be updated with the cluster on which a scanner-pool is allowed. * If role is specified and cluster isn't, then role is applied to the local cluster.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool modify`
    - `vserver vscan scanner-pool apply-policy`
    - `vserver vscan scanner-pool privileged-users add`
    - `vserver vscan scanner-pool privileged-users remove`
    - `vserver vscan scanner-pool servers remove`
    - `vserver vscan scanner-pool servers add`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def post (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Creates a Vscan scanner-pool configuration for a specified SVM. You can create a scanner-pool with all fields specified or only mandatory fields specified.
    Important notes: * A scanner-pool must have servers and privileged users specified. * If the role or cluster is not specified, the scanner-pool is created on the local cluster with the role set as primary. *`Only one of the fields cluster-uuid or cluster-name is required.

    ### Required properties

    - `svm.uuid` or `svm.name` - Existing SVM in which to create the Vscan configuration.
    - `name` - Scanner-pool name.
    - `privileged_users` - List of privileged users.
    - `servers` - List of server IP addresses or FQDNs.

    ### Recommended optional properties

    - `role` - Setting a role for a scanner-pool is recommended.
    - `cluster` - Passing the cluster name or UUID (or both) in a multi-cluster environment is recommended.

    ### Default property values

    If not specified in POST, the following default property values are assigned: * `role` - primary * `cluster.name` - Local cluster name. * `cluster.uuid` - Local cluster UUID.

    ### Related ONTAP commands

    - `vserver vscan scanner-pool create`
    - `vserver vscan scanner-pool apply-policy`
    - `vserver vscan scanner-pool privileged-users add`
    - `vserver vscan scanner-pool servers add`

    ### Learn more

    - `DOC /protocols/vscan/{svm.uuid}/scanner-pools`

    Send this object to the host as a creation request.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class VscanScannerPoolSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VscanScannerPool object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `cluster: Cluster GET POST PATCH`

    The cluster field of the vscan_scanner_pool.

  `name: str GET POST`

    Specifies the name of the scanner pool. Scanner pool name can be up to 256 characters long and is a string that can only contain any combination of ASCII-range alphanumeric characters a-z, A-Z, 0-9), "_", "-" and ".".

    Example: scanner-1

  `privileged_users: List[str] GET POST PATCH`

    Specifies a list of privileged users. A valid form of privileged user-name is "domain-name\user-name". Privileged user-names are stored and treated as case-insensitive strings. Virus scanners must use one of the registered privileged users for connecting to clustered Data ONTAP for exchanging virus-scanning protocol messages and to access file for scanning, remedying and quarantining operations.

    Example: ["cifs\u1","cifs\u2"]

  `role: str GET POST PATCH`

    Specifies the role of the scanner pool. The possible values are:

    - primary - Always active.
    - secondary - Active only when none of the primary external virus-scanning servers are connected.
    - idle - Always inactive.

    Valid choices:

    - primary
    - secondary
    - idle
  `servers: List[str] GET POST PATCH`

    Specifies a list of IP addresses or FQDN for each Vscan server host names which are allowed to connect to clustered ONTAP.

    Example: ["1.1.1.1","10.72.204.27","vmwin204-27.fsct.nb"]

  `svm: Svm GET`

    The svm field of the vscan_scanner_pool.